pub mod utils;
pub mod database;

pub fn test_string(string:String) -> String{
    return string;
}